@@ -1,6 +1,6 @@
 #include "gps.h"
 
-#ifdef Q_WS_MAEMO_5
+#ifdef LIBLOCATION
 
 GpsMaemo5::GpsMaemo5(QObject *parent) : QObject(parent) {
     latitude = 0;
