@@ -1,9 +1,9 @@
 #ifndef GPS_H
 #define GPS_H
 
-#include <QObject>
+#ifdef LIBLOCATION
 
-#ifdef Q_WS_MAEMO_5
+#include <QObject>
 
 extern "C" {
 #include <location/location-gps-device.h>
