@@ -5,11 +5,13 @@
 #include <QtWebKit>
 #include "glatitude.h"
 #include "gps.h"
+#include "gpsfake.h"
 
 class LatitudeGUI : public QMainWindow {
     Q_OBJECT
 
-public slots:
+signals:
+    void newpos();
 
 public:
     LatitudeGUI(QMainWindow *parent = 0);
